@@ -962,6 +962,13 @@ activate (GApplication *app)
   GtkFilterListModel *filter_model;
   GtkFilter *filter;
   GSimpleAction *action;
+  GList *list;
+
+  if ((list = gtk_application_get_windows (GTK_APPLICATION (app))) != NULL)
+    {
+      gtk_window_present (GTK_WINDOW (list->data));
+      return;
+    }
 
   builder = gtk_builder_new_from_resource ("/ui/main.ui");
 
